@@ -26,11 +26,11 @@ sub import {
     return;
 }
 
-die "Perl lib version (v5.8.3) doesn't match executable version ($])"
+die "Perl lib version (v5.8.4) doesn't match executable version ($])"
     unless $^V;
 
-$^V eq v5.8.3
-    or die "Perl lib version (v5.8.3) doesn't match executable version (" .
+$^V eq v5.8.4
+    or die "Perl lib version (v5.8.4) doesn't match executable version (" .
 	sprintf("v%vd",$^V) . ")";
 
 ##
@@ -42,15 +42,15 @@ $^V eq v5.8.3
 #
 ## Package name      : perl5
 ## Source directory  : .
-## Configuration time: Sat Feb 21 18:49:35 CET 2004
+## Configuration time: Sat Jun 26 02:18:47 UTC 2004
 ## Configured by     : Debian Project
-## Target system     : gnu gnu 0.3 gnumach-1.2hurd-0.3 i386-at386 gnu 
+## Target system     : gnu gnu 0.3 gnumach-1.3hurd-0.3 i386-at386 gnu 
 #
 ## Configure command line arguments.
 #PERL_PATCHLEVEL=
 
 our $summary : unique = <<'!END!';
-Summary of my $package (revision $baserev $version_patchlevel_string) configuration:
+Summary of my $package (revision $revision $version_patchlevel_string) configuration:
   Platform:
     osname=$osname, osvers=$osvers, archname=$archname
     uname='$myuname'
@@ -125,11 +125,11 @@ PERL_API_SUBVERSION='0'
 PERL_API_VERSION='8'
 PERL_CONFIG_SH='true'
 PERL_REVISION='5'
-PERL_SUBVERSION='3'
+PERL_SUBVERSION='4'
 PERL_VERSION='8'
 RCSfile='$RCSfile'
 Revision='$Revision'
-SUBVERSION='3'
+SUBVERSION='4'
 Source=''
 State=''
 _a='.a'
@@ -164,11 +164,11 @@ cccdlflags='-fPIC'
 ccdlflags='-Wl,-E'
 ccflags_uselargefiles=''
 ccname='gcc'
-ccsymbols='__GNUC_MINOR__=3 __GNUC_PATCHLEVEL__=2 __GNUC__=3'
+ccsymbols='__GNUC_MINOR__=3 __GNUC_PATCHLEVEL__=3 __GNUC__=3'
 ccversion=''
 cf_by='Debian Project'
 cf_email='perl@packages.debian.org'
-cf_time='Sat Feb 21 18:49:35 CET 2004'
+cf_time='Sat Jun 26 02:18:47 UTC 2004'
 charsize='1'
 chgrp=''
 chmod='chmod'
@@ -180,8 +180,8 @@ config_arg0='Configure'
 config_arg10='-Dvendorlib=/usr/share/perl5'
 config_arg11='-Dvendorarch=/usr/lib/perl5'
 config_arg12='-Dsiteprefix=/usr/local'
-config_arg13='-Dsitelib=/usr/local/share/perl/5.8.3'
-config_arg14='-Dsitearch=/usr/local/lib/perl/5.8.3'
+config_arg13='-Dsitelib=/usr/local/share/perl/5.8.4'
+config_arg14='-Dsitearch=/usr/local/lib/perl/5.8.4'
 config_arg15='-Dman1dir=/usr/share/man/man1'
 config_arg16='-Dman3dir=/usr/share/man/man3'
 config_arg17='-Dsiteman1dir=/usr/local/man/man1'
@@ -195,7 +195,7 @@ config_arg23='-Ud_csh'
 config_arg24='-Uusesfio'
 config_arg25='-Uusenm'
 config_arg26='-Duseshrplib'
-config_arg27='-Dlibperl=libperl.so.5.8.3'
+config_arg27='-Dlibperl=libperl.so.5.8.4'
 config_arg28='-Dd_dosuid'
 config_arg29='-des'
 config_arg2='-Duselargefiles'
@@ -207,7 +207,7 @@ config_arg7='-Dprivlib=/usr/share/perl/5.8'
 config_arg8='-Darchlib=/usr/lib/perl/5.8'
 config_arg9='-Dvendorprefix=/usr'
 config_argc='29'
-config_args='-Dusethreads -Duselargefiles -Dccflags=-DDEBIAN -Dcccdlflags=-fPIC -Darchname=i386-gnu -Dprefix=/usr -Dprivlib=/usr/share/perl/5.8 -Darchlib=/usr/lib/perl/5.8 -Dvendorprefix=/usr -Dvendorlib=/usr/share/perl5 -Dvendorarch=/usr/lib/perl5 -Dsiteprefix=/usr/local -Dsitelib=/usr/local/share/perl/5.8.3 -Dsitearch=/usr/local/lib/perl/5.8.3 -Dman1dir=/usr/share/man/man1 -Dman3dir=/usr/share/man/man3 -Dsiteman1dir=/usr/local/man/man1 -Dsiteman3dir=/usr/local/man/man3 -Dman1ext=1 -Dman3ext=3perl -Dpager=/usr/bin/sensible-pager -Uafs -Ud_csh -Uusesfio -Uusenm -Duseshrplib -Dlibperl=libperl.so.5.8.3 -Dd_dosuid -des'
+config_args='-Dusethreads -Duselargefiles -Dccflags=-DDEBIAN -Dcccdlflags=-fPIC -Darchname=i386-gnu -Dprefix=/usr -Dprivlib=/usr/share/perl/5.8 -Darchlib=/usr/lib/perl/5.8 -Dvendorprefix=/usr -Dvendorlib=/usr/share/perl5 -Dvendorarch=/usr/lib/perl5 -Dsiteprefix=/usr/local -Dsitelib=/usr/local/share/perl/5.8.4 -Dsitearch=/usr/local/lib/perl/5.8.4 -Dman1dir=/usr/share/man/man1 -Dman3dir=/usr/share/man/man3 -Dsiteman1dir=/usr/local/man/man1 -Dsiteman3dir=/usr/local/man/man3 -Dman1ext=1 -Dman3ext=3perl -Dpager=/usr/bin/sensible-pager -Uafs -Ud_csh -Uusesfio -Uusenm -Duseshrplib -Dlibperl=libperl.so.5.8.4 -Dd_dosuid -des'
 contains='grep'
 cp='cp'
 cpio=''
@@ -628,8 +628,8 @@ date='date'
 db_hashtype='u_int32_t'
 db_prefixtype='size_t'
 db_version_major='4'
-db_version_minor='0'
-db_version_patch='14'
+db_version_minor='2'
+db_version_patch='52'
 defvoidused='15'
 direntrytype='struct dirent'
 dlext='so'
@@ -666,7 +666,7 @@ full_csh='csh'
 full_sed='/usr/bin/sed'
 gccansipedantic=''
 gccosandvers=''
-gccversion='3.3.2 (Debian)'
+gccversion='3.3.3 (Debian 20040321)'
 getgrent_r_proto='REENTRANT_PROTO_I_SBWR'
 getgrgid_r_proto='REENTRANT_PROTO_I_TSBWR'
 getgrnam_r_proto='REENTRANT_PROTO_I_CSBWR'
@@ -694,7 +694,7 @@ gidtype='gid_t'
 glibpth='/usr/shlib  /lib /usr/lib /usr/lib/386 /lib/386 /usr/ccs/lib /usr/ucblib /usr/local/lib '
 gmake='gmake'
 gmtime_r_proto='REENTRANT_PROTO_S_TS'
-gnulibc_version='2.3.1'
+gnulibc_version='2.3.2'
 grep='grep'
 groupcat='cat /etc/group'
 groupstype='gid_t'
@@ -798,8 +798,8 @@ i_varargs='undef'
 i_varhdr='stdarg.h'
 i_vfork='undef'
 ignore_versioned_solibs=''
-inc_version_list='5.8.2 5.8.1 5.8.0'
-inc_version_list_init='"5.8.2","5.8.1","5.8.0",0'
+inc_version_list='5.8.3 5.8.2 5.8.1 5.8.0'
+inc_version_list_init='"5.8.3","5.8.2","5.8.1","5.8.0",0'
 incpath=''
 inews=''
 installbin='/usr/bin'
@@ -810,11 +810,11 @@ installman3dir='/usr/share/man/man3'
 installprefix='/usr'
 installprefixexp='/usr'
 installscript='/usr/bin'
-installsitearch='/usr/local/lib/perl/5.8.3'
+installsitearch='/usr/local/lib/perl/5.8.4'
 installsitebin='/usr/local/bin'
 installsitehtml1dir=''
 installsitehtml3dir=''
-installsitelib='/usr/local/share/perl/5.8.3'
+installsitelib='/usr/local/share/perl/5.8.4'
 installsiteman1dir='/usr/local/man/man1'
 installsiteman3dir='/usr/local/man/man3'
 installsitescript='/usr/local/bin'
@@ -843,7 +843,7 @@ ldlibpthname='LD_LIBRARY_PATH'
 less='less'
 lib_ext='.a'
 libc=''
-libperl='libperl.so.5.8.3'
+libperl='libperl.so.5.8.4'
 libsdirs=' /lib'
 libsfiles=' libgdbm.so.3 libgdbm_compat.so.3 libdb.so.3 libdl.so.2 libm.so.6 libpthread.so libcrypt.so.1'
 libsfound=' /lib/libgdbm.so.3 /lib/libgdbm_compat.so.3 /lib/libdb.so.3 /lib/libdl.so.2 /lib/libm.so.6 /lib/libpthread.so /lib/libcrypt.so.1'
@@ -890,7 +890,7 @@ mv=''
 myarchname='i386-AT386-gnu'
 mydomain=''
 myhostname='localhost'
-myuname='gnu gnu 0.3 gnumach-1.2hurd-0.3 i386-at386 gnu '
+myuname='gnu gnu 0.3 gnumach-1.3hurd-0.3 i386-at386 gnu '
 n='-n'
 need_va_copy='undef'
 netdb_hlen_type='size_t'
@@ -932,7 +932,6 @@ pg='pg'
 phostname='hostname'
 pidtype='pid_t'
 plibpth=''
-pm_apiversion='5.005'
 pmake=''
 pr=''
 prefixexp='/usr'
@@ -995,17 +994,17 @@ sig_num='0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26
 sig_num_init='0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 6, 20, 23, 0'
 sig_size='36'
 signal_t='void'
-sitearch='/usr/local/lib/perl/5.8.3'
-sitearchexp='/usr/local/lib/perl/5.8.3'
+sitearch='/usr/local/lib/perl/5.8.4'
+sitearchexp='/usr/local/lib/perl/5.8.4'
 sitebin='/usr/local/bin'
 sitebinexp='/usr/local/bin'
 sitehtml1dir=''
 sitehtml1direxp=''
 sitehtml3dir=''
 sitehtml3direxp=''
-sitelib='/usr/local/share/perl/5.8.3'
+sitelib='/usr/local/share/perl/5.8.4'
 sitelib_stem=''
-sitelibexp='/usr/local/share/perl/5.8.3'
+sitelibexp='/usr/local/share/perl/5.8.4'
 siteman1dir='/usr/local/man/man1'
 siteman1direxp='/usr/local/man/man1'
 siteman3dir='/usr/local/man/man3'
@@ -1039,7 +1038,7 @@ stdio_stream_array=''
 strerror_r_proto='REENTRANT_PROTO_B_IBW'
 strings='/usr/include/string.h'
 submit=''
-subversion='3'
+subversion='4'
 sysman='/usr/share/man/man1'
 tail=''
 tar=''
@@ -1080,6 +1079,7 @@ usefaststdio='define'
 useithreads='define'
 uselargefiles='define'
 uselongdouble='undef'
+usemallocwrap='undef'
 usemorebits='undef'
 usemultiplicity='define'
 usemymalloc='y'
@@ -1121,13 +1121,12 @@ vendorprefix='/usr'
 vendorprefixexp='/usr'
 vendorscript='/usr/bin'
 vendorscriptexp='/usr/bin'
-version='5.8.3'
-version_patchlevel_string='version 8 subversion 3'
+version='5.8.4'
+version_patchlevel_string='version 8 subversion 4'
 versiononly='undef'
 vi=''
 voidflags='15'
 xlibpth='/usr/lib/386 /lib/386'
-xs_apiversion='5.8.3'
 yacc='yacc'
 yaccflags=''
 zcat=''
